\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{ivtuniyarconf}[2023/02/16]
\LoadClass[a5paper]{article}
\RequirePackage[backend=biber,style=gost-numeric,language=auto,autolang=other,sorting=none,movenames=false]{biblatex}
\RequirePackage{indentfirst}
\RequirePackage[colorlinks=true,urlcolor=blue,linkcolor=blue,citecolor=blue]{hyperref}
\RequirePackage[margin=2cm,bottom=2.5cm]{geometry}
\RequirePackage{graphicx}
\RequirePackage{enumitem}
\RequirePackage{url}
\RequirePackage{amsmath}
\RequirePackage{amssymb}
\RequirePackage{amsthm}
\RequirePackage{luacode}

\RequirePackage{microtype}
\RequirePackage{fontspec}
\RequirePackage[english,russian]{babel}
\RequirePackage{unicode-math}
\setmainfont{STIX Two Text}
\setmathfont{STIX Two Math}
\setsansfont{Roboto}[Scale=0.88]
\setmonofont{PT Mono}[Scale=0.94]

\newtheorem{theorem}{Теорема}
\newtheorem{lemma}{Лемма}
\newtheorem{corollary}{Следствие}

\urlstyle{same}
\setlist{nosep}

\renewcommand{\abstractname}{\vspace{-\baselineskip}} %%%%

\clubpenalty=10000 
\widowpenalty=10000

\let\oldbibliography\thebibliography
\renewcommand{\thebibliography}[1]{%
  \oldbibliography{#1}%
  \setlength{\itemsep}{-3pt}%
}
\renewcommand*{\newblockpunct}{\addperiod\space\bibsentence}

\let\footnoterule\relax

\newcommand{\keywords}[1]{\textbf{Ключевые слова:} #1}

\directlua { require('metadata_proc.lua') }

\newcommand\udc[1]{\gdef\@udc{#1}}
\renewcommand{\author}[1]{\luaexec{add_author("#1")}}
\newcommand{\authorstatus}[2]{}
\newcommand{\advisor}[2]{\luaexec{add_advisor("#1", "#2")}}
\newcommand{\affiliation}[1]{\luaexec{set_affiliation("#1")}}
\newcommand{\email}[1]{\luaexec{set_author_email("#1")}}
\newcommand{\advisoremail}[1]{}

\renewcommand\section{\@startsection {section}{1}{\z@}%
  {-2ex \@plus -1ex \@minus -.2ex}%
  {0.5ex \@plus.2ex}%
  {\normalfont\bfseries}}

\renewenvironment{abstract}{%
  \small\quotation\setlength\parindent{0pt}\noindent\textbf{\abstractname.}%
  }
{\vspace*{-3mm}\endquotation\rule{\textwidth}{0.2mm}\vspace*{2mm}}

\def\@maketitle{%
  \setlength{\parindent}{0mm}
  \newpage
  \null
  \vspace*{-7.5mm}
  {\footnotesize

    \begin{center}
      \textsf{Всероссийская молодёжная научно-практическая конференция\\
        «Путь в науку: прикладная математика, информатика и информационные технологии»\\
        Ярославль, ЯрГУ, 17--21 апреля 2023 г.\\
        Секция \ifdef{\confsection}{«\confsection»}{\emph{заполняется оргкомитетом}}}\\[-1mm]
      \rule{\textwidth}{0.2mm}
    \end{center}
    \vspace*{-3mm}  
    УДК \@udc    
  }
  \vspace*{-2mm}
  \begin{center}%
    \let\thefootnote\relax%
    \footnote{\textcopyright\ \directlua{tex.print(output_authors_for_copyright())}, 2023}%
    \textbf{\@title}\par
    \vskip 0.5em%
    \directlua{tex.print(output_authors())}\par
    {\small E-mail: \directlua{tex.print(output_authors_emails())}\par}
    {\small\directlua{tex.print(output_advisors())}\par}
    \vskip 0.5em%
    {\small\directlua{tex.print(output_affiliations())}\par}
  \end{center}
  \par
}

\ifdefined\firstpagenum
\setcounter{page}{\firstpagenum}
\fi
